import java.io.IOException;
import java.io.UncheckedIOException;
import java.util.function.Supplier;

    public class IOExceptionWrapper {

        @FunctionalInterface
        public interface IOCallable<T> {
            T call() throws IOException;
        }

        public static <T> T wrap(IOCallable<T> action) {
            try {
                return action.call();
            } catch (IOException e) {
                throw new UncheckedIOException(e);
            }
        }

        public static void wrapRunnable(IORunnable action) {
            try {
                action.run();
            } catch (IOException e) {
                throw new UncheckedIOException(e);
            }
        }

        @FunctionalInterface
        public interface IORunnable {
            void run() throws IOException;
        }
    }

